==> php54-owncloud-8.0.2.tgz: share/owncloud/apps/files/l10n/km.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "មិន​ស្គាល់​កំហុស",
    "Could not move %s - File with this name already exists" : "មិន​អាច​ផ្លាស់​ទី %s - មាន​ឈ្មោះ​ឯកសារ​ដូច​នេះ​ហើយ",
    "Could not move %s" : "មិន​អាច​ផ្លាស់ទី %s",
    "File name cannot be empty." : "ឈ្មោះ​ឯកសារ​មិន​អាច​នៅ​ទទេ​បាន​ឡើយ។",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "ឈ្មោះ​មិន​ត្រឹម​ត្រូវ, មិន​អនុញ្ញាត '\\', '/', '<', '>', ':', '\"', '|', '?' និង '*' ទេ។",
    "No file was uploaded. Unknown error" : "មិន​មាន​ឯកសារ​ដែល​បាន​ផ្ទុក​ឡើង។ មិន​ស្គាល់​កំហុស",
    "There is no error, the file uploaded with success" : "មិន​មាន​កំហុស​អ្វី​ទេ ហើយ​ឯកសារ​ត្រូវ​បាន​ផ្ទុកឡើង​ដោយ​ជោគជ័យ",
    "Files" : "ឯកសារ",
    "Upload cancelled." : "បាន​បោះបង់​ការ​ផ្ទុក​ឡើង។",
    "{new_name} already exists" : "មាន​ឈ្មោះ {new_name} រួច​ហើយ",
    "Rename" : "ប្ដូរ​ឈ្មោះ",
    "Delete" : "លុប",
    "Unshare" : "លែង​ចែក​រំលែក",
    "Download" : "ទាញយក",
    "Pending" : "កំពុង​រង់ចាំ",
    "Error" : "កំហុស",
    "Name" : "ឈ្មោះ",
    "Size" : "ទំហំ",
    "Modified" : "បាន​កែ​ប្រែ",
    "_%n folder_::_%n folders_" : [""],
    "_%n file_::_%n files_" : [""],
    "_Uploading %n file_::_Uploading %n files_" : [""],
    "_matches '{filter}'_::_match '{filter}'_" : [""],
    "Maximum upload size" : "ទំហំ​ផ្ទុកឡើង​ជា​អតិបរមា",
    "Save" : "រក្សាទុក",
    "Settings" : "ការកំណត់",
    "WebDAV" : "WebDAV",
    "New" : "ថ្មី",
    "Text file" : "ឯកសារ​អក្សរ",
    "New folder" : "ថត​ថ្មី",
    "Folder" : "ថត",
    "From link" : "ពី​តំណ",
    "Upload" : "ផ្ទុក​ឡើង",
    "Cancel upload" : "បោះបង់​ការ​ផ្ទុកឡើង",
    "Upload too large" : "ផ្ទុក​ឡើង​ធំ​ពេក"
},
"nplurals=1; plural=0;");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/files/l10n/km.js <==
OC.L10N.register(
    "files",
    {
    "Unknown error" : "មិន​ស្គាល់​កំហុស",
    "Could not move %s - File with this name already exists" : "មិន​អាច​ផ្លាស់​ទី %s - មាន​ឈ្មោះ​ឯកសារ​ដូច​នេះ​ហើយ",
    "Could not move %s" : "មិន​អាច​ផ្លាស់ទី %s",
    "No file was uploaded. Unknown error" : "មិន​មាន​ឯកសារ​ដែល​បាន​ផ្ទុក​ឡើង។ មិន​ស្គាល់​កំហុស",
    "There is no error, the file uploaded with success" : "មិន​មាន​កំហុស​អ្វី​ទេ ហើយ​ឯកសារ​ត្រូវ​បាន​ផ្ទុកឡើង​ដោយ​ជោគជ័យ",
    "Files" : "ឯកសារ",
    "Upload cancelled." : "បាន​បោះបង់​ការ​ផ្ទុក​ឡើង។",
    "{new_name} already exists" : "មាន​ឈ្មោះ {new_name} រួច​ហើយ",
    "Rename" : "ប្ដូរ​ឈ្មោះ",
    "Delete" : "លុប",
    "Unshare" : "លែង​ចែក​រំលែក",
    "Download" : "ទាញយក",
    "Pending" : "កំពុង​រង់ចាំ",
    "Error" : "កំហុស",
    "Name" : "ឈ្មោះ",
    "Size" : "ទំហំ",
    "Modified" : "បាន​កែ​ប្រែ",
    "File name cannot be empty." : "ឈ្មោះ​ឯកសារ​មិន​អាច​នៅ​ទទេ​បាន​ឡើយ។",
    "You created %1$s" : "អ្នក​បាន​បង្កើត %1$s",
    "%2$s created %1$s" : "%2$s បាន​បង្កើត %1$s",
    "You changed %1$s" : "អ្នក​បាន​ផ្លាស់​ប្ដូរ %1$s",
    "%2$s changed %1$s" : "%2$s បាន​ផ្លាស់​ប្ដូរ %1$s",
    "You deleted %1$s" : "អ្នក​បាន​លុប %1$s",
    "%2$s deleted %1$s" : "%2$s បាន​លុប %1$s",
    "Maximum upload size" : "ទំហំ​ផ្ទុកឡើង​ជា​អតិបរមា",
    "Save" : "រក្សាទុក",
    "Settings" : "ការកំណត់",
    "WebDAV" : "WebDAV",
    "New" : "ថ្មី",
    "Text file" : "ឯកសារ​អក្សរ",
    "New folder" : "ថត​ថ្មី",
    "Folder" : "ថត",
    "Upload" : "ផ្ទុក​ឡើង",
    "Cancel upload" : "បោះបង់​ការ​ផ្ទុកឡើង",
    "Upload too large" : "ផ្ទុក​ឡើង​ធំ​ពេក"
},
"nplurals=1; plural=0;");
